@@ -63,6 +63,14 @@ class File:
         in the Discord client.
     spoiler: :class:`bool`
         Whether the attachment is a spoiler.
+    force_close: :class:`bool`
+        Whether to forcibly close the bytes used to create the file
+        when ``.close()`` is called.
+        This will also make the file bytes unusable by flushing it from
+        memory after it is sent once.
+        Enable this if you don't wish to reuse the same bytes.
+
+        .. versionadded:: 2.2
 
     Attributes
     -----------
@@ -78,15 +86,33 @@ class File:
         in the Discord client.
     spoiler: :class:`bool`
         Whether the attachment is a spoiler.
+    force_close: :class:`bool`
+        Whether to forcibly close the bytes used to create the file
+        when ``.close()`` is called.
+        This will also make the file bytes unusable by flushing it from
+        memory after it is sent or used once.
+        Enable this if you don't wish to reuse the same bytes.
+
+        .. versionadded:: 2.2
     """
 
-    __slots__ = ("fp", "filename", "spoiler", "_original_pos", "_owner", "_closer", "description")
+    __slots__ = (
+        "fp",
+        "filename",
+        "spoiler",
+        "force_close",
+        "_original_pos",
+        "_owner",
+        "_closer",
+        "description",
+    )
 
     if TYPE_CHECKING:
         fp: Union[io.BufferedReader, io.BufferedIOBase]
         filename: Optional[str]
         description: Optional[str]
         spoiler: bool
+        force_close: bool
 
     def __init__(
         self,
@@ -95,6 +121,7 @@ class File:
         *,
         description: Optional[str] = None,
         spoiler: bool = False,
+        force_close: bool = False,
     ):
         if isinstance(fp, io.IOBase):
             if not (fp.seekable() and fp.readable()):
@@ -107,6 +134,8 @@ class File:
             self._original_pos = 0
             self._owner = True
 
+        self.force_close = force_close
+
         # aiohttp only uses two methods from IOBase
         # read and close, since I want to control when the files
         # close, I need to stub it so it doesn't close unless
@@ -145,5 +174,5 @@ class File:
 
     def close(self) -> None:
         self.fp.close = self._closer
-        if self._owner:
+        if self._owner or self.force_close:
             self._closer()
